error.h: Remove some unused errors.
[paraslash.git] / filter.h
index 9e197f6cffb1d45ee46f23f393d6f5781a168b6a..09e45913aa1f116a68e85039a8059f93f13d6822 100644 (file)
--- a/filter.h
+++ b/filter.h
@@ -63,12 +63,12 @@ struct filter_chain {
         * pointer to variable containing the number of bytes loaded in the output buffer
         */
                size_t *out_loaded;
-       /** non-zero if this filter wont' produce any more output */
-       int eof;
-       /** pointer to the eof flag of the receiving application */
-       int *input_eof;
-       /** pointer to the eof flag of the writing application */
-       int *output_eof;
+       /** Non-zero if this filter wont' produce any more output. */
+       int error;
+       /** Pointer to the error variable of the receiving application. */
+       int *input_error;
+       /** Pointer to the eof flag of the writing application. */
+       int *output_error;
        /** the task associated with the filter chain */
        struct task task;
 };